@@ -10,11 +10,11 @@ class DynamicHullNode(BinTreeNode):
             left_supporting=None, right_supporting=None, optimized_subhull_points=None
         ):
         super().__init__(data)
-        self.subhull = SubHullThreadedBinTree.from_iterable(subhull_points)
-        self.optimized_subhull = SubHullThreadedBinTree.from_iterable(optimized_subhull_points if optimized_subhull_points else [])
+        self.subhull = SubhullThreadedBinTree.from_iterable(subhull_points)
+        self.optimized_subhull = SubhullThreadedBinTree.from_iterable(optimized_subhull_points if optimized_subhull_points else [])
         self.left_supporting_index = left_supporting_index
-        self._left_supporting = left_supporting
-        self._right_supporting = right_supporting
+        self.left_supporting = left_supporting
+        self.right_supporting = right_supporting
     
     @property
     def point(self):
@@ -33,6 +33,14 @@ class DynamicHullNode(BinTreeNode):
         subhull = self.subhull.traverse_inorder()
         return self._left_supporting if self._left_supporting else subhull[self.left_supporting_index].point
     
+    @left_supporting.setter
+    def left_supporting(self, value):
+        self._left_supporting = value
+    
+    @left_supporting.deleter
+    def left_supporting(self):
+        del self._left_supporting
+
     @property
     def right_supporting(self):
         subhull = self.subhull.traverse_inorder()
@@ -40,6 +48,14 @@ class DynamicHullNode(BinTreeNode):
             return self._right_supporting if self._right_supporting else subhull[self.left_supporting_index+1].point
         except IndexError:
             return self.left_supporting
+    
+    @right_supporting.setter
+    def right_supporting(self, value):
+        self._right_supporting = value
+    
+    @right_supporting.deleter
+    def right_supporting(self):
+        del self._right_supporting
 
     @property
     def is_point(self):
@@ -157,7 +173,7 @@ class DynamicHullTree(AVLTree):
         return merge(node.left, node.right)
 
 
-class SubHullNode(ThreadedBinTreeNode):
+class SubhullNode(ThreadedBinTreeNode):
     @property
     def point(self):
         return self.data
@@ -171,8 +187,8 @@ class SubHullNode(ThreadedBinTreeNode):
         del self.data
 
 
-class SubHullThreadedBinTree(ThreadedBinTree):
-    node_class = SubHullNode
+class SubhullThreadedBinTree(ThreadedBinTree):
+    node_class = SubhullNode
 
     @classmethod
     def from_iterable(cls, iterable, circular=False):
@@ -310,4 +326,4 @@ def optimize_subhull(node, parent_node):
     parent_points = {n.point for n in parent_node.subhull.traverse_inorder()}
 
     filtered_points = [p for p in node_points if p not in parent_points]
-    node.optimized_subhull = SubHullThreadedBinTree.from_iterable(filtered_points)
+    node.optimized_subhull = SubhullThreadedBinTree.from_iterable(filtered_points)
